==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ToolActionIconMenuInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionIconButtonInfoDescriptionMetadata } from "./ToolActionIconButtonInfoDescriptionMetadata";
import { ToolActionIconMenuInfoDescription } from "./ToolActionIconMenuInfoDescription";
/**
 * @hidden
 */
export let ToolActionIconMenuInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionIconMenuInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionIconMenuInfoDescriptionMetadata.a == null) {
                ToolActionIconMenuInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionIconMenuInfoDescriptionMetadata.c(ToolActionIconMenuInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionIconMenuInfoDescriptionMetadata.a)) {
                return;
            }
            a.ab(ToolActionIconMenuInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionIconButtonInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionIconMenuInfoDescriptionMetadata.b(a);
            a.ad("ToolActionIconMenuInfo", () => new ToolActionIconMenuInfoDescription());
            a.ac("ToolActionIconMenuInfo", ToolActionIconMenuInfoDescriptionMetadata.a);
        }
    }
    ToolActionIconMenuInfoDescriptionMetadata.$t = markType(ToolActionIconMenuInfoDescriptionMetadata, 'ToolActionIconMenuInfoDescriptionMetadata');
    ToolActionIconMenuInfoDescriptionMetadata.a = null;
    return ToolActionIconMenuInfoDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ToolActionIconMenuInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionIconButtonInfoDescriptionMetadata } from "./ToolActionIconButtonInfoDescriptionMetadata";
import { ToolActionIconMenuInfoDescription } from "./ToolActionIconMenuInfoDescription";
/**
 * @hidden
 */
export let ToolActionIconMenuInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionIconMenuInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionIconMenuInfoDescriptionMetadata.a == null) {
                ToolActionIconMenuInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionIconMenuInfoDescriptionMetadata.c(ToolActionIconMenuInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionIconMenuInfoDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolActionIconMenuInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionIconButtonInfoDescriptionMetadata.c(a);
            a.item("ShowArrowIcon", "Boolean");
        }
        static d(a) {
            ToolActionIconMenuInfoDescriptionMetadata.b(a);
            a.ae("ToolActionIconMenuInfo", () => new ToolActionIconMenuInfoDescription());
            a.ad("ToolActionIconMenuInfo", ToolActionIconMenuInfoDescriptionMetadata.a);
        }
    }
    ToolActionIconMenuInfoDescriptionMetadata.$t = markType(ToolActionIconMenuInfoDescriptionMetadata, 'ToolActionIconMenuInfoDescriptionMetadata');
    ToolActionIconMenuInfoDescriptionMetadata.a = null;
    return ToolActionIconMenuInfoDescriptionMetadata;
})();
